@@ -164,6 +164,8 @@ function(doc, control = list())
         .tokenize <- MC_tokenizer
     else if (identical(.tokenize, "scan"))
         .tokenize <- scan_tokenizer
+    else if (NLP::is.Span_Tokenizer(.tokenize))
+        .tokenize <- NLP::as.Token_Tokenizer(.tokenize)
     if (is.function(.tokenize))
         txt <- .tokenize(doc)
     else
@@ -238,9 +240,9 @@ function(doc, control = list())
     tab <- tab[(nc >= lb) & (nc <= ub)]
 
     ## Return named integer
-    structure(as.integer(tab),
-              names = names(tab),
-              class = c("term_frequency", "integer"))
+    storage.mode(tab) <- "integer"
+    class(tab) <- c("term_frequency", class(tab))
+    tab
 }
 
 print.TermDocumentMatrix <-
